BMDS Python interface
=====================

.. image:: https://img.shields.io/pypi/v/bmds.svg
        :target: https://pypi.python.org/pypi/bmds

.. image:: https://img.shields.io/pypi/wheel/bmds.svg
    :target: https://pypi.python.org/pypi/bmds/
    :alt: Wheel Status

.. image:: https://ci.appveyor.com/api/projects/status/9vuiyl71io1xu8h7?svg=true
        :target: https://ci.appveyor.com/project/shapiromatron/bmds

.. image:: https://readthedocs.org/projects/bmds/badge/?version=latest
        :target: https://bmds.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

This Python package is designed to run the U.S. EPA BMDS_ software from a python
interface. The toolkit is currently used in the following projects:

- The Health Assessment Workspace Collaborative (`HAWC`_)
- `BMDS server`_

It requires Python3.5+.

.. _`BMDS`: https://www.epa.gov/bmds
.. _`HAWC`: https://hawcproject.org
.. _`BMDS server`: https://github.com/shapiromatron/bmds-server/
